from sqlalchemy import Column, Integer, String, create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker


engine = create_engine('sqlite:///db.db', convert_unicode=True)


Base = declarative_base()


class User(Base):
    __tablename__ = 'users'

    id = Column(Integer, primary_key=True)
    username = Column(String, nullable=False, unique=True)
    passwordhash = Column(String, nullable=False)


def init_db():
    Base.metadata.create_all(bind=engine)


class Session:
    session = None

    def __enter__(self):
        self.session = Session.create()
        return self.session

    @staticmethod
    def create():
        factory = sessionmaker(autocommit=False,
                               autoflush=False,
                               bind=engine)
        return factory()

    def __exit__(self, exc_type, exc_val, exc_tb):
        self.session.close()
